<?php

namespace Drupal\content_translation_redirect;

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Provides an interface defining a Content Translation Redirect entity.
 */
interface ContentTranslationRedirectInterface extends ConfigEntityInterface {

  /**
   * The ID of the default content translation redirect.
   */
  public const DEFAULT_ID = 'default';

  /**
   * Sets the redirect status code.
   *
   * @param int|null $code
   *   The redirect status code.
   */
  public function setStatusCode(?int $code): void;

  /**
   * Gets the redirect status code.
   *
   * @return int|null
   *   The redirect status code.
   */
  public function getStatusCode(): ?int;

  /**
   * Gets the redirect status code label.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The redirect status code label.
   */
  public function getStatusCodeLabel(): TranslatableMarkup;

  /**
   * Returns whether this redirect is locked.
   *
   * @return bool
   *   Whether the redirect is locked or not.
   */
  public function isLocked(): bool;

}
